@@ -58,8 +58,8 @@ API Reference
 #include "sqlite3.h"
 #endif
 
-#if SQLITE_VERSION_NUMBER < 3007016
-#error Your SQLite version is too old.  It must be at least 3.7.16
+#if SQLITE_VERSION_NUMBER < 3008002
+#error Your SQLite version is too old.  It must be at least 3.8.2
 #endif
 
 /* system headers */
@@ -281,7 +281,8 @@ sqliteshutdown(void)
   SQLITE_CONFIG_SERIALIZED, SQLITE_CONFIG_URI, SQLITE_CONFIG_MEMSTATUS
   and SQLITE_CONFIG_COVERING_INDEX_SCAN.
 
-  See :func:`log` for an example of using SQLITE_CONFIG_LOG.
+  See :ref:`tips <diagnostics_tips>` for an example of how to receive
+  log messages (SQLITE_CONFIG_LOG)
 
   -* sqlite3_config
 */
@@ -1126,7 +1127,6 @@ formatsqlvalue(APSW_ARGUNUSED PyObject *self, PyObject *value)
   my code with the actual docstring from tools.py:main().
 */
 
-#ifdef EXPERIMENTAL
 /** .. method:: log(level, message)
 
     Calls the SQLite logging interface.  Note that you must format the
@@ -1134,18 +1134,8 @@ formatsqlvalue(APSW_ARGUNUSED PyObject *self, PyObject *value)
 
         apsw.log(apsw.SQLITE_NOMEM, "Need %d bytes of memory" % (1234,))
 
-    To set your own logger use::
-
-        def handler(errcode, message):
-           print errcode, message
-        apsw.config(apsw.SQLITE_CONFIG_LOG, handler)
-
-    *handler* will be called with two arguments.  The first will be a
-    numeric error code and the second will be a message string.  Note
-    that the handler has to be set before any other calls to SQLite.
-    Once SQLite is initialised you cannot change the logger - a
-    :exc:`MisuseError` will happen (this restriction is in SQLite not
-    APSW).
+    See :ref:`tips <diagnostics_tips>` for an example of how to
+    receive log messages.
 
     -* sqlite3_log
  */
@@ -1160,8 +1150,6 @@ apsw_log(APSW_ARGUNUSED PyObject *self, PyObject *args)
   PyMem_Free(message);
   Py_RETURN_NONE;
 }
-#endif
-
 
 static PyMethodDef module_methods[] = {
   {"sqlite3_sourceid", (PyCFunction)get_sqlite3_sourceid, METH_NOARGS,
@@ -1219,7 +1207,6 @@ static PyMethodDef module_methods[] = {
   {0, 0, 0, 0}  /* Sentinel */
 };
 
-
 static void add_shell(PyObject *module);
 
 
@@ -1496,6 +1483,12 @@ modules etc. For example::
       ADDINT(SQLITE_IOERR_MMAP),
       ADDINT(SQLITE_NOTICE_RECOVER_ROLLBACK),
       ADDINT(SQLITE_NOTICE_RECOVER_WAL),
+      ADDINT(SQLITE_BUSY_SNAPSHOT),
+      ADDINT(SQLITE_IOERR_GETTEMPPATH),
+      ADDINT(SQLITE_WARNING_AUTOINDEX),
+      ADDINT(SQLITE_CANTOPEN_CONVPATH),
+      ADDINT(SQLITE_IOERR_CONVPATH),
+      ADDINT(SQLITE_CONSTRAINT_ROWID),
       END,
 
       /* error codes */
@@ -1593,6 +1586,7 @@ modules etc. For example::
       ADDINT(SQLITE_CONFIG_COVERING_INDEX_SCAN),
       ADDINT(SQLITE_CONFIG_SQLLOG),
       ADDINT(SQLITE_CONFIG_MMAP_SIZE),
+      ADDINT(SQLITE_CONFIG_WIN32_HEAPSIZE),
       END,
 
       DICT("mapping_db_config"),
@@ -1626,6 +1620,7 @@ modules etc. For example::
       ADDINT(SQLITE_DBSTATUS_CACHE_HIT),
       ADDINT(SQLITE_DBSTATUS_CACHE_MISS),
       ADDINT(SQLITE_DBSTATUS_CACHE_WRITE),
+      ADDINT(SQLITE_DBSTATUS_DEFERRED_FKS),
       END,
 
       DICT("mapping_locking_level"),
@@ -1688,6 +1683,7 @@ modules etc. For example::
       ADDINT(SQLITE_FCNTL_BUSYHANDLER),
       ADDINT(SQLITE_FCNTL_TEMPFILENAME),
       ADDINT(SQLITE_FCNTL_MMAP_SIZE),
+      ADDINT(SQLITE_FCNTL_TRACE),
       END
 
       };
